/***************************************************************/
/* MQCHLCLI : this pgm is a  channel receive exit,             */
/*            can be use for debugging purpose.                */
/*            It log some MQCD fields:                         */
/*                                                             */
/*               ChannelName                                   */
/*               Transporttype                                 */
/*               ConnectionName                                */
/*                                                             */
/*            At the end of the pgm, the channel is stop to    */
/*            prevent the flow of message from this channel.   */
/*                                                             */
/*                                                             */
/* parametre: DEBUG                                            */
/*                                                             */
/*                                                             */
/* To activate the pgm, do the following command:              */
/*                                                             */
/*  ALT CHL(xxxxxxx) CHLTYPE(xxxxx) MSGEXIT('MQCHLCLI')        */
/*      MSGDATA('DEBUG')                                       */
/*                                                             */
/*                                                             */
/* Michel Jalette avril/2001 (CGI)                             */
/*                                                             */
/***************************************************************/
/* Define code CSECT name */
#pragma csect(code,"CSQ4BX2")
/* Define static CSECT name */
#pragma csect(static,"BCX2WS")

#pragma runopts(nostae,nospie)
#pragma environment(MQCHLCLI)

const char * EyeCatcher = "MQCHLCLI" ;
const char * auteur     = "MJALETTE-CGI";
const char * DateStamp  = __DATE__;
const char * TimeStamp  = __TIME__;

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <spc.h>
#include <cmqc.h>
#include <cmqxc.h>

/***************************************************************/
/* Program procedure with parameters                           */
/***************************************************************/

int MQCHLCLI(
             PMQCXP   pMQCXP,
             PMQCD    pMQCD,
             PMQLONG  pDataLength,
             PMQLONG  pAgentBufferLength,
             PMQBYTE  pAgentBuffer,
             PMQLONG  pExitBufferLength,
             PMQPTR   pExitBufferAddr
             )
{

int  ch;
int  result, offset;
int  debug           = 0;
char *cresult ;
PMQXQH pMQXQH;
PMQMD  pMQMD;

/***************************************************************/
/* Check the MQCXP StrucId, Version, and ExitId                */
/***************************************************************/

  cresult= strstr(pMQCXP-> ExitData,"DEBUG");
  if (cresult != NULL) {
    printf("*------- MQCHLCLI User Exit started -------*\n");
    debug = 1;
  }

  result = strncmp(pMQCXP-> StrucId, MQCXP_STRUC_ID, 4);
  if (result != 0) {
      printf("MQCXP StrucId = %.4s\n", pMQCXP->StrucId);
  }

  if (pMQCXP-> Version != MQCXP_CURRENT_VERSION) {
      printf("MQCXP Version Error\n");
  }

  switch(pMQCXP -> ExitId)
  {
    case MQXT_CHANNEL_RCV_EXIT:
      if (debug) printf("ExitId         = Receive\n");
      break;
    default:
      printf("Not a RCV Exit\n");
      break;
  }

  switch (pMQCXP -> ExitReason)
  {
    case MQXR_INIT:
      if (debug) printf("ExitReason     = Initialization\n");
      break;
    case MQXR_TERM:
      if (debug) printf("ExitReason     = Termination\n");
      break;
    case MQXR_MSG:
      if (debug) printf("ExitReason     = Process a message\n");
      break;
    case MQXR_AUTO_CLUSSDR:
      if (debug) printf("ExitReason     = Auto CLUSSDR\n");
      break;

    case MQXR_AUTO_CLUSRCVR:
      if (debug) printf("ExitReason     = Auto CLUSRCVR\n");
      break;
    case MQXR_XMIT:
      if (debug) printf("ExitReason     = XMIT \n");
      break;
    default:
      printf("Invalid ExitReason :%i\n",pMQCXP->ExitReason);
      break;
  }


/***************************************************************/
/* Print selected MQCD fields                                  */
/***************************************************************/

  if (pMQCD-> Version != MQCD_CURRENT_VERSION) {
      printf("MQCD Version Error\n");
  }

  if ( pMQCXP -> ExitReason == MQXR_INIT) {
   if (debug) {
      printf("ChannelName    = %.20s\n", pMQCD -> ChannelName);
      printf("Transporttype  = %i\n", pMQCD -> TransportType);
      printf("ConnectionName = %.264s\n", pMQCD -> ConnectionName);
   }
  }


/***************************************************************/
/* Set response codes                                          */
/***************************************************************/


  pMQCXP -> ExitResponse = MQXCC_CLOSE_CHANNEL;

}
